#encoding: utf-8
# ------------------------------
# Mod pour \pokemonsdk\scripts\01600 Scene_Battle\00400_Scene_Battle_Functions_p4.rb
# ------------------------------
# Ajout de la def phase4_evolve_check + appel de cette def au moment du level up
# La perte d'effroi, de satiété et de gaieté au level up a été rajoutée par mes soins sur détection automatique de Loyalty Overhaul.
# Ajout d'un mécanisme de citation plus variés selon les bonus du gain d'XP, avec détection automatique de XP_OVERHAUL.

#noyard
# Description: Définition de fonctions utiles ou d'animations pendant la phase 4
class Scene_Battle

	#===
	#>phase4_evolve_check
	# Vérification de l'évolution de chacun des Pokémons
	#===
	def phase4_evolve_check(pokemon, index) # PSDK 24.68 - Rajouter "form" en argument si ça crashe
		id, form = pokemon.evolve_check(:level_up)
		if (id)
			Graphics.freeze
			@message_window.visible = false
			GamePlay::Evolve.new(pokemon, id, form).main unless pokemon.dead?

			if index < @actor_sprites.length
				@actor_sprites[index].reload
			end

			@viewport.visible = true
			Graphics.transition
		end
	end
 
	remove_const :EXP_SOUND
	EXP_SOUND = 'audio/se/BW_exp'
	remove_const :LVL_SOUND
	LVL_SOUND = 'audio/me/rosa_levelup'
	#===
	# Animation of the experience distribution to one Pokemon
	# @param battler [PFM::Pokemon] Pokemon receiving the exp
	# @param exp_amount [Integer] number of exp point to distribute
	# @param index [Integer] index of the battler in the battler array
	# quote [Integer] (facultatif) : n° de la phrase à afficher pour le gain d'XP (déterminé depuis le mod XP Overhaul - la détection automatique permet de ne pas y avoir de dépendance)
	#===
	def phase4_distribute_exp_animation(battler, exp_amount, index, quote = 0)
		# Display exp message
		csv = 18
		str = 43
		if defined?(XP_OVERHAUL) # Je prévoirais d'autres phrases du CSV plus tard.
			case quote
			when 1,2,4
				str = 44
			end
		else
			if battler.item_db_symbol == :"exp._share" || battler.item_db_symbol == :"lucky_egg"
				str = 44
			end
		end
		text = parse_text(csv, str, '[VAR 010C(0000)]' => battler.given_name, NUM7R => exp_amount.to_s)
		display_message(text)
		final_exp = battler.exp + exp_amount
		# Distribution loop
		while battler.exp < final_exp && battler.level < $pokemon_party.level_max_limit
			exp_delta = (battler.exp_lvl - battler.exp_list[battler.level]) / 104
			exp_delta = 1 if exp_delta <= 0
			Audio.se_play(EXP_SOUND)
			# Current level exp distribution
			while battler.exp < final_exp && battler.exp < battler.exp_lvl
				# Add & calibration
				battler.exp = (battler.exp + exp_delta).clamp(0, battler.exp_lvl).clamp(0, final_exp)
				# Show bar animation
				next unless index < $game_temp.vs_type
				status_bar_update(battler)
				Graphics.update
				update_animated_sprites
			end
			Audio.se_stop
			# Level up sequence if needed
			if battler.exp >= battler.exp_lvl
				list = battler.level_up_stat_refresh
				status_bar_update(battler) if index < $game_temp.vs_type
				Audio.me_play(LVL_SOUND)
				PFM::Text.set_num3(battler.level.to_s, 1)
				display_message(parse_text(18, 62, '[VAR 010C(0000)]' => battler.given_name))
				PFM::Text.reset_variables
				battler.level_up_window_call(list[0], list[1], @message_window.z + 5) if @actors.include?(battler) # battler.position >= 0
				@message_window.update
				Graphics.update									   
				update_animated_sprites
				# Loyalty Overhaul : Pertes de satiété et de gaieté pour montée de niveau
				if defined?(LOYALTY_OVERHAUL)
					battler.enjoyment -= 20
					battler.fullness -= 20
					# --- On calcule le palier d'XP pour la perte d'effroi ---
					if defined?(XP_OVERHAUL)
						column = levelling_tier(battler)
						battler.dread -= 2**column
						puts "Perte d'effroi : #{2**column}"
					else # Taux standard si XP_OVERHAUL n'est pas détecté
						battler.dread -= 8
					end
					# --- Fin du calcul du palier d'XP ---
					battler.level_with_original_trainer = battler.level if ($trainer.id == battler.trainer_id and $trainer.name == battler.trainer_name)
					#puts "Level with original trainer mis à jour" if ($trainer.id == battler.trainer_id and $trainer.name == battler.trainer_name) # Pour tester si cette ligne n'est pas bypassée dans les autres cas de montée de niveau.
				end
				battler.check_skill_and_learn		
				# @_Evolve << battler unless @_Evolve.include?(battler) -----------------------------	<= Ligne neutralisée
				phase4_evolve_check(battler, index) # -------------------------------------------	<= Ligne ajoutée
			end
		end
	end
end